"use strict";
/**
 * @module Flexbox abstraction
 *
 * -webkit- is needed for mobile safari (iPad)
 */
var src_1 = require("../src");
/**
 * If you have more than one child prefer horizontal,vertical
 */
exports.flexRoot = {
    display: [
        '-webkit-flex',
        'flex'
    ]
};
/**
 * A general grouping component that has no impact on the parent flexbox properties e.g.
 * <vertical>
 *    <pass>
 *       <content/>
 *    </pass>
 * </vertical>
 */
exports.pass = {
    display: 'inherit',
    '-webkit-flex-direction': 'inherit',
    flexDirection: 'inherit',
    '-webkit-flex-grow': 1,
    flexGrow: 1
};
exports.inlineRoot = {
    display: 'inline-flex'
};
exports.horizontal = src_1.extend(exports.flexRoot, {
    '-webkit-flex-direction': 'row',
    flexDirection: 'row'
});
exports.vertical = src_1.extend(exports.flexRoot, {
    '-webkit-flex-direction': 'column',
    flexDirection: 'column'
});
exports.wrap = {
    '-webkit-flex-wrap': 'wrap',
    flexWrap: 'wrap'
};
exports.flexNone = {
    flex: 'none'
};
/**
 * If you want items to be sized automatically by their children use this
 * This is because of a bug in various flexbox implementations: http://philipwalton.com/articles/normalizing-cross-browser-flexbox-bugs/
 */
exports.content = {
    '-webkit-flex-shrink': 0,
    flexShrink: 0
};
exports.flex = {
    '-webkit-flex': 1,
    flex: 1
};
exports.flex1 = exports.flex;
exports.flex2 = {
    '-webkit-flex': 2,
    flex: 2
};
exports.flex3 = {
    '-webkit-flex': 3,
    flex: 3
};
exports.flex4 = {
    '-webkit-flex': 4,
    flex: 4
};
exports.flex5 = {
    '-webkit-flex': 5,
    flex: 5
};
exports.flex6 = {
    '-webkit-flex': 6,
    flex: 6
};
exports.flex7 = {
    '-webkit-flex': 7,
    flex: 7
};
exports.flex8 = {
    '-webkit-flex': 8,
    flex: 8
};
exports.flex9 = {
    '-webkit-flex': 9,
    flex: 9
};
exports.flex10 = {
    '-webkit-flex': 10,
    flex: 10
};
exports.flex11 = {
    '-webkit-flex': 11,
    flex: 11
};
exports.flex12 = {
    '-webkit-flex': 12,
    flex: 12
};
/////////////////////////////
// Alignment in cross axis //
/////////////////////////////
exports.start = {
    '-webkit-align-items': 'flex-start',
    alignItems: 'flex-start'
};
exports.center = {
    '-webkit-align-items': 'center',
    alignItems: 'center'
};
exports.end = {
    '-webkit-align-items': 'flex-end',
    alignItems: 'flex-end'
};
////////////////////////////
// Alignment in main axis //
////////////////////////////
exports.startJustified = {
    '-webkit-justify-content': 'flex-start',
    justifyContent: 'flex-start'
};
exports.centerJustified = {
    '-webkit-justify-content': 'center',
    justifyContent: 'center'
};
exports.endJustified = {
    '-webkit-justify-content': 'flex-end',
    justifyContent: 'flex-end'
};
exports.aroundJustified = {
    '-webkit-justify-content': 'space-around',
    justifyContent: 'space-around'
};
exports.betweenJustified = {
    '-webkit-justify-content': 'space-between',
    justifyContent: 'space-between'
};
////////////////////////////
// Alignment in both axes //
////////////////////////////
exports.centerCenter = src_1.extend(exports.flexRoot, exports.center, exports.centerJustified);
////////////////////
// Self alignment //
////////////////////
exports.selfStart = {
    '-webkit-align-self': 'flex-start',
    alignSelf: 'flex-start'
};
exports.selfCenter = {
    '-webkit-align-self': 'center',
    alignSelf: 'center'
};
exports.selfEnd = {
    '-webkit-align-self': 'flex-end',
    alignSelf: 'flex-end'
};
exports.selfStretch = {
    '-webkit-align-self': 'stretch',
    alignSelf: 'stretch'
};
